@@ -8,8 +8,8 @@ use warnings;
 use File::Spec ();
 
 # ABSTRACT: Get information about a class and its structure
-our $VERSION = '1.33_01'; # TRIAL VERSION
-$VERSION = eval $VERSION;
+our $VERSION = '1.35_01'; # TRIAL VERSION
+$VERSION = eval $VERSION; ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 
 # If Unicode is available, enable it so that the
@@ -17,7 +17,10 @@ $VERSION = eval $VERSION;
 # We can safely ignore any failure here.
 BEGIN {
   local $@;
-  eval "require utf8; utf8->import";
+  eval {
+    require utf8;
+    utf8->import;
+  };
 }
 
 # Predefine some regexs
@@ -224,7 +227,8 @@ sub methods {
   while ( my $cl = shift @queue ) {
     push @path, $cl;
     unshift @queue, grep { ! $seen{$_}++ }
-      map { s/^::/main::/; s/\'/::/g; $_ }
+      map { s/^::/main::/; s/\'/::/g; $_ } ##  no critic
+      map { "$_" }
       ( @{"${cl}::ISA"} );
   }
 
@@ -300,7 +304,7 @@ sub subclasses {
 sub _subnames {
   my ($class, $name) = @_;
   return sort
-    grep {
+    grep {  ## no critic
       substr($_, -2, 2, '') eq '::'
       and
       /$RE_IDENTIFIER/o
@@ -326,7 +330,7 @@ sub children {
 
   # Find all the Foo:: elements in our symbol table
   no strict 'refs';
-  map { "${name}::$_" } sort grep { s/::$// } keys %{"${name}::"};
+  map { "${name}::$_" } sort grep { s/::$// } keys %{"${name}::"};  ## no critic
 }
 
 # As above, but recursively
@@ -342,7 +346,7 @@ sub recursive_children {
   while ( my $namespace = $children[$i++] ) {
     push @children, map { "${namespace}::$_" }
       grep { ! /^::/ } # Ignore things like ::ISA::CACHE::
-      grep { s/::$// }
+      grep { s/::$// }  ## no critic
       keys %{"${namespace}::"};
   }
 
@@ -407,7 +411,7 @@ Class::Inspector - Get information about a class and its structure
 
 =head1 VERSION
 
-version 1.33_01
+version 1.35_01
 
 =head1 SYNOPSIS
 
